@@ -288,6 +288,11 @@ int set_jobexid(
 
   struct group *gpent;
   char  *puser = NULL;
+  char  *id = "set_jobexid";
+  char *at;
+  char *usr_at_host = NULL;
+  int len;
+
 
   struct passwd *pwent = NULL;
   char  *pgrpn;
@@ -326,7 +331,33 @@ int set_jobexid(
       else
         pattr = &pjob->ji_wattr[(int)JOB_ATR_userlst];
 
-      if ((puser = geteusernam(pjob, pattr)) == NULL)
+      if (pjob->ji_wattr[JOB_ATR_proxy_user].at_flags & ATR_VFLAG_SET)
+        {
+        puser = pjob->ji_wattr[JOB_ATR_proxy_user].at_val.at_str;
+
+        /* set the job's owner as the new user */
+        at = strchr(pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str,'@');
+        len = strlen(puser) + 1;
+        if (at != NULL)
+          {
+          len += strlen(at);
+          usr_at_host = (char *)malloc(len * sizeof(char));
+          snprintf(usr_at_host,len,"%s%s",
+            puser,
+            at);
+          }
+        else
+          {
+          usr_at_host = (char *)malloc(len * sizeof(char));
+
+          snprintf(usr_at_host,len,"%s",
+            puser);
+          }
+
+        free(pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str);
+        pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str = usr_at_host;
+        }
+      else if ((puser = geteusernam(pjob, pattr)) == NULL)
         {
         if (EMsg != NULL)
           snprintf(EMsg, 1024, "cannot locate user name in job");
@@ -364,17 +395,64 @@ int set_jobexid(
 
     if (pwent == NULL)
       {
-      log_err(errno, "set_jobexid", "getpwnam failed");
+      snprintf(log_buffer,sizeof(log_buffer),
+        "User %s does not exist in server password file\n",
+        puser);
+
+      log_err(errno, id, log_buffer);
 
       if (EMsg != NULL)
-        snprintf(EMsg, 1024, "user does not exist in server password file");
+        snprintf(EMsg,1024,"%s",log_buffer);
 
       return(PBSE_BADUSER);
       }
 
     if (pwent->pw_uid == 0)
       {
-      if (server.sv_attr[(int)SRV_ATR_AclRoot].at_flags & ATR_VFLAG_SET)
+      /* add check here for virtual user */
+      if (pjob->ji_wattr[JOB_ATR_proxy_user].at_flags & ATR_VFLAG_SET)
+        {
+        puser = pjob->ji_wattr[JOB_ATR_proxy_user].at_val.at_str;
+
+        pwent = getpwnam(puser);
+
+        if (pwent == NULL)
+          {
+          snprintf(log_buffer,sizeof(log_buffer),
+            "User %s does not exist in server password file\n",
+            puser);
+
+          log_err(errno, id, log_buffer);
+
+          if (EMsg != NULL)
+            snprintf(EMsg,1024,"%s",log_buffer);
+
+          return(PBSE_BADUSER);
+          }
+
+        /* set the job's owner as the new user */
+        at = strchr(pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str,'@');
+        len = strlen(puser) + 1;
+        if (at != NULL)
+          {
+          len += strlen(at);
+          usr_at_host = (char *)malloc(len * sizeof(char));
+          snprintf(usr_at_host,len,"%s%s",
+            puser,
+            at);
+          }
+        else
+          {
+          usr_at_host = (char *)malloc(len * sizeof(char));
+
+          snprintf(usr_at_host,len,"%s",
+            puser);
+          }
+
+        free(pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str);
+        pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str = usr_at_host;
+        }
+      else if (server.sv_attr[(int)SRV_ATR_AclRoot].at_flags & ATR_VFLAG_SET)
         {
         if (acl_check(
               &server.sv_attr[(int)SRV_ATR_AclRoot],
@@ -498,7 +576,7 @@ int set_jobexid(
       }
     else
       {
-      log_err(errno, "set_jobexid", "getpwnam failed");
+      log_err(errno, id, "getpwnam failed");
 
       if (EMsg != NULL)
         snprintf(EMsg, 1024, "user does not exist in server password file");
@@ -561,11 +639,15 @@ int set_jobexid(
       if (*pmem == NULL)
         {
         /* requested group not allowed */
+        snprintf(log_buffer,sizeof(log_buffer),
+          "user %s is not a member of group %s in server password file",
+          puser,
+          pgrpn);
+
+        log_err(-1,id,log_buffer);
 
         if (EMsg != NULL)
-          snprintf(EMsg, 1024, "user %s not member of group %s in server password file",
-                   puser,
-                   pgrpn);
+          snprintf(EMsg, 1024, "%s",log_buffer);
 
         return(PBSE_BADGRP); /* user not in group */
         }
